@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: reducers
 version: 3.12.1
-id: reducers-3.12.1-5059a359a1ef18c98ef337a1c3c7f247
-key: reduc_FRn3Dq31DRtKVh1NrYWNdH
+id: reducers-3.12.1-f0d1b50cfbdb1add57ff9cbb6041f153
+key: reduc_8M8yW9P76i8BYQqdO6JVmv
 license: BSD3
 copyright: Copyright (C) 2008-2013 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,7 +26,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/reducers-3.12.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/reducers-3.12.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/reducers-3.12.1
-hs-libraries: HSreducers-3.12.1-FRn3Dq31DRtKVh1NrYWNdH
+hs-libraries: HSreducers-3.12.1-8M8yW9P76i8BYQqdO6JVmv
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -34,7 +34,7 @@ depends:
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    semigroupoids-5.0.1-53b0b3ecfca9d658a051ef7b22e11130
+    semigroupoids-5.0.1-ab1721c6c7a72801e6cd851407a313ad
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
